@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 from functools import partial, wraps
 
@@ -175,13 +175,31 @@ class View(object):
             invoking
             request: Request
         
+        As mentioned, you can pass in more than one decorator at a time, and
+        they will be *applied* in reverse order, hence *running* in the order
+        you provide:
+        
+            >>> def decorator2(func):
+            ...     def wrapper(*args, **kwargs):
+            ...         print 'wrapping 2'
+            ...         return func(*args, **kwargs)
+            ...     return wrapper
+            
+            >>> _ = X._decorate(decorator, decorator2)('Request')
+            wrapping
+            wrapping 2
+            invoking
+            request: Request
+        
         """
         
+        new_method = cls.__new__
         for decorator in decorators[::-1]:
-            cls = type(cls.__name__, (cls,), {
-                '__new__': staticmethod(method_decorator(decorator)(cls.__new__)),
-            })
-        return cls
+            new_method = method_decorator(decorator)(new_method)
+        
+        return type(cls.__name__, (cls,), {
+            '__new__': staticmethod(new_method),
+        })
     
     # You might need to override this method.
     def __init__(self, request, *args, **kwargs):
@@ -205,12 +223,12 @@ def method_decorator(decorator):
     typical class-based view, the first argument will be `self`, so you won't be
     able to use the standard decorators. Until now!
     
-    `methodist()` wraps a function decorator to produce a new method decorator.
-    Use it like this:
+    `method_decorator()` wraps a function decorator to produce a new method
+    decorator. Use it like this:
     
         class MyClassBasedView(object):
             
-            @methodist(login_required)
+            @method_decorator(login_required)
             def __call__(self, request, *args, **kwargs):
                 do_something()
     
